@@ -16,6 +16,7 @@ import datetime
 import subprocess
 import shutil
 import csv
+import pkg_resources
 # mine
 import preprocess_dataset
 import features
@@ -82,9 +83,17 @@ def get_project_root():
     # At this point it can be sure that the configuration file exists
     # Now make sure the project structure exists
     for dirname in ["raw-datasets", "preprocessed", "feature-files", "models"]:
-        directory = os.path.join(cfg['root'], "raw-datasets/info.yml")
+        directory = os.path.join(cfg['root'], dirname)
         if not os.path.exists(directory):
             os.makedirs(directory)
+
+    # TODO: How to check for updates if it already exists?
+    raw_data_dst = os.path.join(cfg['root'], "raw-datasets/info.yml")
+    if not os.path.isfile(raw_data_dst):
+        raw_yml_path = pkg_resources.resource_filename('hwrt', 'misc/')
+        raw_yml_pkg_src = os.path.join(raw_yml_path, "info.yml")
+        shutil.copy(raw_yml_pkg_src, raw_data_dst)
+
     return cfg['root']
 
 
